.. _compatible_api:

Compatible ensembles
======================

.. automodule:: imbalanced_ensemble.ensemble.compatible
    :no-members:
    :no-inherited-members:

.. currentmodule:: imbalanced_ensemble.ensemble.compatible

.. autosummary::
   :toctree: _autosummary
   :template: class.rst

   CompatibleAdaBoostClassifier
   CompatibleBaggingClassifier
